@@ -94,11 +94,12 @@ int SendHotplugSignal(void)
 
 	if (pid != -1)
 	{
-		Log2(PCSC_LOG_INFO, "Send hotplug signal to pcscd (pid=%d)", pid);
+		Log2(PCSC_LOG_INFO, "Send hotplug signal to pcscd (pid=%ld)",
+			(long)pid);
 		if (kill(pid, SIGUSR1) < 0)
 		{
-			Log3(PCSC_LOG_CRITICAL, "Can't signal pcscd (pid=%d): %s",
-				pid, strerror(errno));
+			Log3(PCSC_LOG_CRITICAL, "Can't signal pcscd (pid=%ld): %s",
+				(long)pid, strerror(errno));
 			return EXIT_FAILURE ;
 		}
 		(void)SYS_Sleep(1);
@@ -167,7 +168,9 @@ int ThreadCreate(pthread_t * pthThread, int attributes,
 	if (ret)
 		goto error;
 
-	if (stack_size < 0x40000)
+	/* A stack_size of 0 indicates the default size on Solaris.
+	 * The default size is more than 256 KB so do not shrink it. */
+	if ((stack_size != 0) && (stack_size < 0x40000))
 	{
 		stack_size = 0x40000;
 		ret = pthread_attr_setstacksize(&attr, stack_size);
